@@ -777,7 +777,7 @@ function footer() {
 		<div style=\"font-size:0.5em;\">
 			<img style=\"height:60px; width:60px; float:left;\" src=\"$imagepath\" alt=\"Splash Page: For access to the Internet.\">
 			&copy; The openNDS Project 2015 - $year<br>
-			openNDS $version
+			Portal Version: $version
 			<br><br><br><br>
 		</div>
 		</div>
@@ -981,10 +981,10 @@ function insert_css() {
 	echo "
 	body {
 		background-color: lightgrey;
-		color: black;
-		margin-left: 5%;
-		margin-right: 5%;
-		text-align: left;
+		color: #140f07;
+		margin: 0;
+		padding: 10px;
+		font-family: sans-serif;
 	}
 
 	hr {
@@ -995,10 +995,11 @@ function insert_css() {
 		margin-right:auto;
 		border-style:inset;
 		border-width:5px;
-	} 
+	}
 
 	.offset {
 		background: rgba(300, 300, 300, 0.6);
+		border-radius: 10px;
 		margin-left:auto;
 		margin-right:auto;
 		max-width:600px;
@@ -1009,63 +1010,74 @@ function insert_css() {
 	.insert {
 		background: rgba(350, 350, 350, 0.7);
 		border: 2px solid #aaa;
-		border-radius: 4px;
+		border-radius: 10px;
 		min-width:200px;
 		max-width:100%;
 		padding: 5px;
 	}
 
+	.insert > h1 {
+		font-size: medium;
+		margin: 0 0 15px;
+	}
+
 	img {
 		width: 40%;
 		max-width: 180px;
 		margin-left: 0%;
-		margin-right: 5%;
+		margin-right: 10px;
+		border-radius: 3px;
 	}
 
-	input[type=text], input[type=email], input[type=password] {
+	input[type=text], input[type=email], input[type=password], input[type=number], input[type=tel] {
 		font-size: 1em;
-		line-height: 2.0em;
-		height: 2.0em;
-		width: 14.0em;
-		color: black;
+		line-height: 2em;
+		height: 2em;
+		color: #0c232a;
 		background: lightgrey;
 	}
 
 	input[type=submit], input[type=button] {
-		font-size: 1em;
-		line-height: 2.0em;
-		height: 2.0em;
-		width: 14.0em;
-		color: black;
+			font-size: 1em;
+		line-height: 2em;
+		height: 2em;
 		font-weight: bold;
-		background: lightblue;
+		border: 0;
+		border-radius: 10px;
+		background-color: #1a7856;
+		padding: 0 10px;
+		color: #fff;
+		cursor: pointer;
+		box-shadow: rgba(50, 50, 93, 0.1) 0 0 0 1px inset,
+		rgba(50, 50, 93, 0.1) 0 2px 5px 0, rgba(0, 0, 0, 0.07) 0 1px 1px 0;
 	}
 
 	med-blue {
 		font-size: 1.2em;
-		color: blue;
+		color: #0073ff;
 		font-weight: bold;
 		font-style: normal;
 	}
 
 	big-red {
 		font-size: 1.5em;
-		color: red;
+		color: #c20801;
 		font-weight: bold;
 	}
 
 	italic-black {
-		font-size: 1.0em;
-		color: black;
+		font-size: 1em;
+		color: #0c232a;
 		font-weight: bold;
 		font-style: italic;
+		margin-bottom: 10px;
 	}
 
 	copy-right {
 		font-size: 0.7em;
 		color: darkgrey;
 		font-weight: bold;
-		font-style:italic;
+		font-style: italic;
 	}
 
 	";
