@@ -22,6 +22,7 @@
   @brief Client List Functions
   @author Copyright (C) 2004 Alexandre Carmel-Veillex <acv@acv.ca>
   @author Copyright (C) 2007 Paul Kube <nodogsplash@kokoro.ucsd.edu>
+  @author Copyright (C) 2015-2022 Modifications and additions by BlueWave Projects and Services <opennds@blue-wave.net>
  */
 
 #define _GNU_SOURCE
@@ -129,6 +130,8 @@ _client_list_append(const char mac[], const char ip[])
 	}
 
 	client->id = client_id;
+	client->out_packet_limit = 0;
+	client->inc_packet_limit = 0;
 
 	debug(LOG_NOTICE, "Adding %s %s token %s to client list",
 		client->ip, client->mac, client->token ? client->token : "none");
@@ -197,6 +200,9 @@ t_client *
 client_list_add_client(const char mac[], const char ip[])
 {
 	t_client *client;
+	int rc = -1;
+	char *libcmd;
+	char *msg;
 
 	if (!check_mac_format(mac)) {
 		// Inappropriate format in IP address
@@ -210,7 +216,20 @@ client_list_add_client(const char mac[], const char ip[])
 		return NULL;
 	}
 
+	// check if client ip was allocated by dhcp
+	safe_asprintf(&libcmd, "/usr/lib/opennds/libopennds.sh dhcpcheck \"%s\"", ip);
+	msg = safe_calloc(64);
+	rc = execute_ret_url_encoded(msg, 64 - 1, libcmd);
+	free(libcmd);
+
+	if (rc > 0) {
+		// IP address is not in the dhcp database
+		debug(LOG_NOTICE, "IP not allocated by dhcp [%s]", ip);
+		return NULL;
+	}
+
 	client = client_list_find(mac, ip);
+
 	if (!client) {
 		client = _client_list_append(mac, ip);
 	} else {
@@ -221,7 +240,7 @@ client_list_add_client(const char mac[], const char ip[])
 }
 
 /** Finds a client by its token, IP or MAC.
- * A found client is guaranted to be unique.
+ * A found client is guaranteed to be unique.
  * @param ip IP we are looking for in the linked list
  * @param mac MAC we are looking for in the linked list
  * @return Pointer to the client, or NULL if not found
