@@ -88,6 +88,27 @@ static pthread_t tid_client_check = 0;
 // Time when opennds started
 time_t started_time = 0;
 
+static void catcher(int sig) {
+}
+
+static void ignore_sigpipe(void) {
+	struct sigaction oldsig;
+	struct sigaction sig;
+
+	sig.sa_handler = &catcher;
+	sigemptyset (&sig.sa_mask);
+	#ifdef SA_INTERRUPT
+	sig.sa_flags = SA_INTERRUPT;  /* SunOS */
+	#else
+	sig.sa_flags = SA_RESTART;
+	#endif
+	if (0 != sigaction (SIGPIPE, &sig, &oldsig)) {
+		fprintf (stderr, "Failed to install SIGPIPE handler: %s\n", strerror (errno));
+	}
+}
+
+
+
 /**@internal
  * @brief Handles SIGCHLD signals to avoid zombie processes
  *
@@ -647,7 +668,7 @@ setup_from_config(void)
 
 	// If PreAuth is enabled, override any FAS configuration and check script exists
 	if (config->preauth) {
-		debug(LOG_NOTICE, "Preauth is Enabled - Overiding FAS configuration.\n");
+		debug(LOG_NOTICE, "Preauth is Enabled - Overriding FAS configuration.\n");
 		debug(LOG_INFO, "Preauth Script is %s\n", config->preauth);
 
 
@@ -866,7 +887,7 @@ setup_from_config(void)
 	}
 
 	// Preload remote files defined in themespec
-	if (config->login_option_enabled == 3 && routercheck > 0) {
+	if (routercheck > 0) {
 		download_remotes(1);
 		// Initial download is in progress, so sleep for a while before starting watchdog thread.
 		sleep(2);
@@ -892,6 +913,14 @@ setup_from_config(void)
 	}
 	free(debuglevel);
 
+	write_ndsinfo();
+
+	// Test for Y2.038K bug
+
+	if (sizeof(time_t) == 4) {
+		debug(LOG_WARNING, "WARNING - Year 2038 bug detected in system (32 bit time). Continuing.....");
+	}
+
 	debug(LOG_NOTICE, "openNDS is now running.\n");
 }
 
@@ -910,6 +939,8 @@ main_loop(void)
 	// Set up everything we need based on the configuration
 	setup_from_config();
 
+	ignore_sigpipe();
+
 	// Start watchdog, client statistics and timeout clean-up thread
 	result = pthread_create(&tid_client_check, NULL, thread_client_timeout_check, NULL);
 	if (result != 0) {
@@ -978,3 +1009,5 @@ int main(int argc, char **argv)
 
 	return 0; // never reached
 }
+
+
